@@ -1,9 +1,12 @@
 import logging
+from datetime import datetime
 from os import path
 from src.api import oking
 import sys
+import src.api.okvendas as api_okvendas
+from src.entities.log import Log
 
-global is_connected_oracle_client, client_data
+global is_connected_oracle_client, client_data, start_time
 
 logging.basicConfig(level=logging.DEBUG,
                     format='[%(levelname)s][%(asctime)s] %(message)s',
@@ -19,21 +22,34 @@ def print_version():
     exit(0)
 
 
-def get_token_from_params(args: list) -> str:
+def get_token_from_params(args: list) -> (str, bool):
     if len(args) >= 2:
         if args[1] == '--version':
             print_version()
-        return args[1]
+
+        if len(args) >= 3 and args[2] == '--dev':
+            return args[1], True
+
+        return args[1], False
     else:
         logger.error('Informe o token da integracao como parametro')
         exit(1)
 
 
-token_oking = get_token_from_params(sys.argv)
+token_oking, is_dev = get_token_from_params(sys.argv)
+
+start_time = datetime.now().isoformat()
 logger.info('Iniciando oking __init__')
+logger.info(f'Ambiente: {"Dev" if is_dev else "Prod"}')
+if not is_dev:
+    # Consultar dados da integracao do cliente (modulos, tempo de execucao, dados api okvendas)
+    client_data = oking.get(f'https://appbuilder.openk.com.br/api/consulta/integracao_oking/filtros?token={token_oking}', None)
+    api_okvendas.post_log(Log(f'Oking inicializando {client_data["integracao_id"]}', datetime.now().isoformat(), '', 'INICIALIZACAO'))
+else:
+    # Consultar dados da integracao do cliente em ambiente node-red local
+    client_data = oking.get(f'http://127.0.0.1:1880/api/consulta/integracao_oking/filtros', None)
+    api_okvendas.post_log(Log(f'Oking inicializando cliente id {client_data["integracao_id"]}', datetime.now().isoformat(), '', 'INICIALIZACAO'))
 
-# Consultar dados da integracao do cliente (modulos, tempo de execucao, dados api okvendas)
-client_data = oking.get(f'https://appbuilder.openk.com.br/api/consulta/integracao_oking/filtros?token={token_oking}', None)
 
 if client_data is not None:
     assert client_data['integracao_id'] is not None, 'Id da integracao nao informado (Api Oking)'
